@@ -3,7 +3,7 @@
  * @copyright Copyright (c) 2016 Bjoern Schiessle <bjoern@schiessle.org>
  * @copyright Copyright (c) 2017 Lukas Reschke <lukas@statuscode.ch>
  *
- * @author Bjoern Schiessle <bjoern@schiessle.org>
+ * @author Joas Schilling <coding@schilljs.com>
  * @author Lukas Reschke <lukas@statuscode.ch>
  *
  * @license GNU AGPL version 3 or any later version
@@ -23,15 +23,5 @@
  *
  */
 
-$logger = \OC::$server->getLogger();
-$userSession = \OC::$server->getUserSession();
-$groupManager = \OC::$server->getGroupManager();
-$eventDispatcher = \OC::$server->getEventDispatcher();
-
-$auditLogger = new \OCA\Admin_Audit\AuditLogger(
-	$logger,
-	$userSession,
-	$groupManager,
-	$eventDispatcher
-);
-$auditLogger->registerHooks();
+$app = new \OCA\AdminAudit\AppInfo\Application();
+$app->register();
