@@ -66,10 +66,11 @@ OC.L10N.register(
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Ongelma sivun lataamisessa, päivitetään %n sekunnin kuluttua","Ongelma sivun lataamisessa, päivitetään %n sekunnin kuluttua"],
     "Saving..." : "Tallennetaan...",
     "Dismiss" : "Hylkää",
-    "Authentication required" : "Tunnistautuminen vaaditaan",
     "This action requires you to confirm your password" : "Toiminto vaatii vahvistamista salasanallasi",
-    "Confirm" : "Vahvista",
+    "Authentication required" : "Tunnistautuminen vaaditaan",
     "Password" : "Salasana",
+    "Cancel" : "Peruuta",
+    "Confirm" : "Vahvista",
     "Failed to authenticate, try again" : "Varmennus epäonnistui, yritä uudelleen",
     "seconds ago" : "sekunteja sitten",
     "Logging in …" : "Kirjaudutaan sisään...",
@@ -95,7 +96,6 @@ OC.L10N.register(
     "Already existing files" : "Jo olemassa olevat tiedostot",
     "Which files do you want to keep?" : "Mitkä tiedostot haluat säilyttää?",
     "If you select both versions, the copied file will have a number added to its name." : "Jos valitset kummatkin versiot, kopioidun tiedoston nimeen lisätään numero.",
-    "Cancel" : "Peruuta",
     "Continue" : "Jatka",
     "(all selected)" : "(kaikki valittu)",
     "({count} selected)" : "({count} valittu)",
@@ -103,8 +103,6 @@ OC.L10N.register(
     "Pending" : "Odottaa",
     "Copy to {folder}" : "Kopioi kansioon {folder}",
     "Move to {folder}" : "Siirrä kansioon {folder}",
-    "New in" : "Uutta versiossa",
-    "View changelog" : "Katso muutosloki",
     "Very weak password" : "Erittäin heikko salasana",
     "Weak password" : "Heikko salasana",
     "So-so password" : "Kohtalainen salasana",
@@ -121,14 +119,20 @@ OC.L10N.register(
     "The PHP OPcache is not properly configured. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">For better performance it is recommended</a> to use the following settings in the <code>php.ini</code>:" : "PHP Opcache ei ole määritelty oikein. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Suosittelemme käyttämään paremman suorituskyvyn saavuttamiseksi ↗</a> seuraavia asetuksia <code>php.ini</code>-asetustiedostossa:",
     "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "PHP-funktio \"set_time_limit\" ei ole käytettävissä. Tämä saattaa johtaa siihen, että skriptien suoritus päättyy ennenaikaisesti ja Nextcloud-asennus rikkoutuu. Funktion käyttäminen on erittäin suositeltavaa.",
     "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "PHP-asennuksessasi ei ole FreeType-tukea, ja siitä aiheutuu profiilikuvien sekä asetuskäyttöliittymän rikkoutuminen.",
-    "Missing index \"{indexName}\" in table \"{tableName}\"." : "Puuttuva indeksi \"{indexName}\" taulussa \"{tableName}\".",
     "Error occurred while checking server setup" : "Virhe palvelimen määrityksiä tarkistaessa",
     "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Data-hakemisto ja tiedostot ovat luultavasti käytettävissä suoraan Internetistä. .htaccess-tiedosto ei toimi oikein. Suosittelemme määrittämään HTTP-palvelimen asetukset siten, ettei data-hakemisto ole suoraan käytettävissä Internetistä tai siirtämään data-hakemiston HTTP-palvelimen juurihakemiston ulkopuolelle.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP-header \"{header}\" ei ole määritetty vastaamaan arvoa \"{expected}\". Kyseessä on mahdollinen tietoturvaan tai -suojaan liittyvä riski, joten on suositeltavaa muuttaa asetuksen arvoa.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "HTTP-header \"{header}\" ei ole määritetty vastaamaan arvoa \"{expected}\". Jotkin toiminnot eivät vättämättä toimi oikein, joten on suositeltavaa muuttaa asetuksen arvoa.",
+    "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the <a href=\"{docUrl}\" rel=\"noreferrer noopener\">security tips</a>." : "HTTP-header \"Strict-Transport-Security\" ei ole määritelty vähintään \"{seconds}\" sekuntiin. Paremman tietoturvan vuoksi on suositeltavaa määritellä HSTS:n, kuten <a href=\"{docUrl}\" rel=\"noreferrer noopener\">tietoturvavinkeissä</a> neuvotaan.",
+    "Accessing site insecurely via HTTP. You are strongly adviced to set up your server to require HTTPS instead, as described in the <a href=\"{docUrl}\">security tips</a>." : "Käytät sivustoa HTTP-yhteydellä. On suositeltavaa, että palvelin vaatiii HTTPS-yhteyden, kuten <a href=\"{docUrl}\">tietoturvavinkeissä</a> neuvotaan.",
     "Shared" : "Jaettu",
     "Shared with" : "Jaettu",
     "Shared by" : "Jaettu",
+    "Error setting expiration date" : "Virhe vanhenemispäivää asetettaessa",
+    "The public link will expire no later than {days} days after it is created" : "Julkinen linkki vanhenee {days} päivän jälkeen sen luomisesta",
+    "Set expiration date" : "Aseta vanhenemispäivä",
+    "Expiration" : "Vanheneminen",
+    "Expiration date" : "Vanhenemispäivä",
     "Choose a password for the public link" : "Valitse salasana julkiselle linkille",
     "Choose a password for the public link or press the \"Enter\" key" : "Valitse salasana julkiselle linkille tai paina \"Enter\" näppäintä",
     "Copied!" : "Kopioitu!",
@@ -137,7 +141,7 @@ OC.L10N.register(
     "Press Ctrl-C to copy." : "Paina Ctrl-C kopioidaksesi.",
     "Resharing is not allowed" : "Jakaminen uudelleen ei ole sallittu",
     "Share to {name}" : "Jaa henkilölle {name}",
-    "Copy URL" : "Kopioi osoite",
+    "Share link" : "Jaa linkki",
     "Link" : "Linkki",
     "Password protect" : "Suojaa salasanalla",
     "Allow editing" : "Salli muokkaus",
@@ -146,17 +150,12 @@ OC.L10N.register(
     "Allow upload and editing" : "Salli lähetys ja muokkaus",
     "Read only" : "Vain luku",
     "File drop (upload only)" : "Tiedostojen pudotus (Vain lähetys)",
-    "Set expiration date" : "Aseta vanhenemispäivä",
-    "Expiration" : "Vanheneminen",
-    "Expiration date" : "Vanhenemispäivä",
-    "Share link" : "Jaa linkki",
     "Shared with you and the group {group} by {owner}" : "Jaettu sinun ja ryhmän {group} kanssa käyttäjältä {owner}",
     "Shared with you by {owner}" : "Jaettu kanssasi käyttäjältä {owner}",
     "Choose a password for the mail share" : "Valitse salasana sähköpostijaolle",
     "{{shareInitiatorDisplayName}} shared via link" : "{{shareInitiatorDisplayName}} jakoi linkillä",
     "group" : "ryhmä",
     "remote" : "etä",
-    "remote group" : "etäryhmä",
     "email" : "sähköposti",
     "shared by {sharer}" : "jakanut {sharer}",
     "Unshare" : "Lopeta jakaminen",
@@ -261,13 +260,9 @@ OC.L10N.register(
     "Need help?" : "Tarvitsetko apua?",
     "See the documentation" : "Tutustu ohjeisiin",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Tämä sovellus vaatii toimiakseen JavaScript-tuen. {linkstart}Ota JavaScript käyttöön{linkend} ja päivitä sivu.",
-    "Skip to main content" : "Siirry pääsisältöön",
     "More apps" : "Lisää sovelluksia",
     "Search" : "Etsi",
     "Reset search" : "Tyhjennä haku",
-    "Contacts" : "Yhteystiedot",
-    "Contacts menu" : "Yhteystietovalikko",
-    "Settings menu" : "Asetusvalikko",
     "Confirm your password" : "Vahvista salasanasi",
     "Server side authentication failed!" : "Palvelimen puoleinen tunnistautuminen epäonnistui!",
     "Please contact your administrator." : "Ota yhteys ylläpitäjään.",
@@ -279,7 +274,6 @@ OC.L10N.register(
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Useita virheellisiä kirjautumisyrityksiä havaittiin IP-osoitteestasi. Siksi seuraava yritys sallitaan vasta 30:n sekunnin päästä.",
     "Forgot password?" : "Unohditko salasanasi?",
     "Back to login" : "Palaa kirjautumiseen",
-    "Connect to your account" : "Yhdistä tiliisi",
     "App token" : "Sovellusvaltuutus",
     "Grant access" : "Myönnä pääsy",
     "Account access" : "Tilin käyttö",
@@ -287,8 +281,6 @@ OC.L10N.register(
     "Redirecting …" : "Ohjataan uudelleen…",
     "New password" : "Uusi salasana",
     "New Password" : "Uusi salasana",
-    "This share is password-protected" : "Jako on salasanasuojattu",
-    "The password is wrong. Try again." : "Salasana on väärin. Yritä uudelleen.",
     "Two-factor authentication" : "Kaksivaiheinen tunnistautuminen",
     "Enhanced security is enabled for your account. Please authenticate using a second factor." : "Tililläsi on käytössä parannettu tietoturva. Käytä tunnistuksen toista vaihetta.",
     "Cancel log in" : "Peru kirjautuminen",
@@ -329,8 +321,6 @@ OC.L10N.register(
     "The \"Strict-Transport-Security\" HTTP header is not configured to at least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\" rel=\"noreferrer\">security tips</a>." : "HTTP-header \"Strict-Transport-Security\" ei ole määritelty vähintään \"{seconds}\" sekuntiin. Paremman tietoturvan vuoksi on suositeltavaa määritellä HSTS, kuten <a href=\"{docUrl}\" rel=\"noreferrer\">tietoturvavinkeissä</a> neuvotaan.",
     "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "Käytät sivustoa HTTP-yhteydellä. On suositeltavaa, että palvelin vaatii HTTPS-yhteyden, kuten <a href=\"{docUrl}\">tietoturvavinkeissä</a> neuvotaan.",
     "Shared with {recipients}" : "Jaettu henkilöiden {recipients} kanssa",
-    "Error setting expiration date" : "Virhe vanhenemispäivää asetettaessa",
-    "The public link will expire no later than {days} days after it is created" : "Julkinen linkki vanhenee {days} päivän jälkeen sen luomisesta",
     "Share with other people by entering a user or group, a federated cloud ID or an email address." : "Jaa muille kirjoittamalla käyttäjä tai ryhmä, federoidun pilven tunniste tai sähköpostiosoite.",
     "Share with other people by entering a user or group or a federated cloud ID." : "Jaa muille kirjoittamalla käyttäjä, ryhmä tai federoidun pilven tunniste.",
     "Share with other people by entering a user or group or an email address." : "Jaa muille kirjoittamalla käyttäjä, ryhmä tai sähköpostiosoite.",
@@ -348,8 +338,6 @@ OC.L10N.register(
     "Add \"%s\" as trusted domain" : "Lisää \"%s\" luotetuksi verkkotunnukseksi",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "Jos tarvitset apua, katso <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">ohjeista</a>.",
     "Your PHP does not have freetype support. This will result in broken profile pictures and settings interface." : "PHP:ssäsi ei ole freetype-tukea. Tämä johtaa rikkinäisiin profiilikuviin ja rikkinäiseen asetuskäyttöliittymään.",
-    "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the <a href=\"{docUrl}\" rel=\"noreferrer noopener\">security tips</a>." : "HTTP-header \"Strict-Transport-Security\" ei ole määritelty vähintään \"{seconds}\" sekuntiin. Paremman tietoturvan vuoksi on suositeltavaa määritellä HSTS:n, kuten <a href=\"{docUrl}\" rel=\"noreferrer noopener\">tietoturvavinkeissä</a> neuvotaan.",
-    "Accessing site insecurely via HTTP. You are strongly adviced to set up your server to require HTTPS instead, as described in the <a href=\"{docUrl}\">security tips</a>." : "Käytät sivustoa HTTP-yhteydellä. On suositeltavaa, että palvelin vaatiii HTTPS-yhteyden, kuten <a href=\"{docUrl}\">tietoturvavinkeissä</a> neuvotaan.",
     "Back to log in" : "Palaa kirjautumiseen",
     "Depending on your configuration, this button could also work to trust the domain:" : "Asetuksista riippuen, ylläpitäjänä saatat pystyä alla olevalla painikkeella lisäämään tämän verkkotunnuksen luotetuksi."
 },
