@@ -1,85 +1,125 @@
 OC.L10N.register(
     "settings",
     {
-    "Enabled" : "Ενεργοποιημένο",
-    "Not enabled" : "Μη ενεργοποιημένο",
+    "{actor} changed your password" : "{actor} το συθηματικό σας άλλαξε",
+    "You changed your password" : "Αλλάξατε το συνθηματικό σας",
+    "Your password was reset by an administrator" : "Έχει γίνει επαναφορά του συνθηματικού σας από τον διαχειριστή",
+    "{actor} changed your email address" : "{actor} άλλαξε τη διεύθυνσή του ηλεκτρονικού ταχυδρομείου σας",
+    "You changed your email address" : "Έχετε αλλάξει τη διεύθυνση ηλεκτρονικού ταχυδρομείου σας",
+    "Your email address was changed by an administrator" : "Η διεύθυνση ηλεκτρονικής αλληλογραφίας άλλαξε από τον διαχειριστή",
+    "Security" : "Ασφάλεια",
+    "You successfully logged in using two-factor authentication (%1$s)" : "Έχετε συνδεθεί επιτυχώς με τη χρήση ελέγχου ταυτότητας δύο-παραγόντων (%1$s)",
+    "A login attempt using two-factor authentication failed (%1$s)" : "Μία προσπάθεια σύνδεσης με τη χρήση ελέγχου ταυτότητας δύο-παραγόντων απέτυχε (%1$s)",
+    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Ο δικός σας <ισχυρός>κωδικός πρόσβασης</ισχυρός>ή<ισχυρός>αλληλογραφίας</ισχυρός>τροποποιήθηκε",
+    "Your apps" : "Οι εφαρμογές σας",
+    "Updates" : "Ενημερώσεις",
+    "Enabled apps" : "Ενεργοποιημένες εφαρμογές",
+    "Disabled apps" : "Απενεργοποιημένες εφαρμογές",
+    "App bundles" : "Πακέτα εφαρμογών",
     "Wrong password" : "Εσφαλμένο συνθηματικό",
     "Saved" : "Αποθηκεύτηκαν",
     "No user supplied" : "Δεν εισήχθη χρήστης",
     "Unable to change password" : "Αδυναμία αλλαγής συνθηματικού",
     "Authentication error" : "Σφάλμα πιστοποίησης",
-    "Please provide an admin recovery password, otherwise all user data will be lost" : "Παρακαλώ παρέχετε έναν κωδικό ανάκτησης διαχειριστή, διαφορετικά όλα τα δεδομένα χρήστη θα χαθούν",
+    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Παρακαλώ παρέχετε έναν κωδικό ανάκτησης διαχειριστή, διαφορετικά όλα τα δεδομένα χρήστη θα χαθούν.",
     "Wrong admin recovery password. Please check the password and try again." : "Λάθος κωδικός ανάκτησης διαχειριστή. Παρακαλώ ελέγξτε τον κωδικό και δοκιμάστε ξανά.",
-    "Backend doesn't support password change, but the user's encryption key was successfully updated." : "Το σύστημα δεν υποστηρίζει αλλαγή κωδικού, αλλά το κλειδί κρυπτογράφησης του χρήστη ενημερώθηκε επιτυχώς.",
+    "Backend doesn't support password change, but the user's encryption key was updated." : "Το σύστημα δεν υποστηρίζει αλλαγή κωδικού, αλλά το κλειδί κρυπτογράφησης του χρήστη ενημερώθηκε επιτυχώς.",
     "installing and updating apps via the app store or Federated Cloud Sharing" : "εγκατάσταση και ενημέρωση εφαρμογών μέσω του καταστήματος εφαρμογών ή του ",
     "Federated Cloud Sharing" : "Διαμοιρασμός σε ομόσπονδα σύννεφα ",
     "cURL is using an outdated %s version (%s). Please update your operating system or features such as %s will not work reliably." : "Το cURL χρησιμοποιεί μια παρωχημένη %s έκδοση (%s). Παρακαλούμε αναβαθμίστε το λειτουργικό σας σύστημα αλλιώς δυνατότητες όπως %s δεν θα δουλέψουν αξιόπιστα.",
-    "A problem occurred, please check your log files (Error: %s)" : "Παρουσιάστηκε πρόβλημα, παρακαλώ ελέγξτε τα αρχεία καταγραφής σας (Σφάλμα: %s)",
-    "Migration Completed" : "Η μετάβαση ολοκληρώθηκε",
     "Group already exists." : "Η ομάδα υπάρχει ήδη.",
     "Unable to add group." : "Αδυναμία προσθήκης ομάδας.",
     "Unable to delete group." : "Αδυναμία διαγραφής ομάδας.",
-    "test email settings" : "δοκιμή ρυθμίσεων email",
+    "Invalid SMTP password." : "Μη έγκυρο συνθηματικό SMTP.",
+    "Email setting test" : "Δοκιμή ρυθμίσεων email",
+    "Well done, %s!" : "Συγχαρητήρια, %s!",
+    "If you received this email, the email configuration seems to be correct." : "Εάν λάβατε αυτό το μήνυμα ηλεκτρονικού ταχυδρομείου, ",
+    "Email could not be sent. Check your mail server log" : "Το μήνυμα ηλεκτρονικού ταχυδρομείου δεν εστάλη. Ελέγξτε το αρχείο καταγραφής.",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Παρουσιάστηκε σφάλμα κατά την αποστολή e-mail. Παρακαλώ ελέγξτε τις ρυθμίσεις σας.(Error: %s)",
-    "Email sent" : "Το Email απεστάλη ",
     "You need to set your user email before being able to send test emails." : "Πρέπει να ορίσετε το email του χρήστη πριν να είστε σε θέση να στείλετε δοκιμαστικά emails.",
-    "Invalid request" : "Μη έγκυρο αίτημα",
     "Invalid mail address" : "Μη έγκυρη διεύθυνση ταχυδρομείου.",
+    "No valid group selected" : "Δεν επιλέθηκε έγκυρη ομάδα",
     "A user with that name already exists." : "Υπάρχει ήδη χρήστης με το ίδιο όνομα",
+    "To send a password link to the user an email address is required." : "Για να στείλετε ένα σύνδεσμο συνθηματικού στον χρήστη μια διεύθυνση ηλεκτρονικού ταχυδρομείου είναι απαραίτητη.",
     "Unable to create user." : "Αδυναμία δημιουργίας χρήστη.",
-    "Your %s account was created" : "Ο λογαριασμός %s δημιουργήθηκε",
     "Unable to delete user." : "Αδυναμία διαγραφής χρήστη.",
+    "Error while enabling user." : "Σφάλμα κατά την ενεργοποίηση χρήστη.",
+    "Error while disabling user." : "Σφάλμα κατά την απενεργοποίηση χρήστη.",
+    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Για να επιβεβαιώσετε τον λογαριασμό σας στο Twitter, δημοσιεύστε την παρακάτω δημοσίευση στο Twitter (σιγουρευτείτε ότι την δημοσιεύετε χωρίς χαρακτήρες αλλαγής γραμμής)",
+    "Settings saved" : "Οι ρυθμίσεις αποθηκεύτηκαν",
     "Unable to change full name" : "Δεν ήταν δυνατή η αλλαγή του πλήρους ονόματός σας",
+    "Unable to change email address" : "Αδυναμία αλλαγής διεύθυνσης ηλεκτρονικής αλληλογραφίας",
     "Your full name has been changed." : "Το πλήρες όνομά σας άλλαξε.",
     "Forbidden" : "Δεν επιτρέπεται",
     "Invalid user" : "Μη έγκυρος χρήστης",
     "Unable to change mail address" : "Αδυναμία αλλαγής διεύθυνσης αλληλογραφίας",
     "Email saved" : "Το email αποθηκεύτηκε ",
+    "%1$s changed your password on %2$s." : "%1$sάλλαξε το συνθηματικό σε %2$s.",
+    "Your password on %s was changed." : "Ο κωδικός πρόσβασης στο %s έχει αλλάξει.",
+    "Your password on %s was reset by an administrator." : "Έχει γίνει επαναφορά του κωδικού πρόσβασης στο %s από τον διαχειριστή.",
+    "Password for %1$s changed on %2$s" : "Ο κωδικός πρόσβασης για το %1$s άλλαξε σε %2$s",
+    "Password changed for %s" : "Το συνθηματικό άλλαξε για τον %s",
+    "If you did not request this, please contact an administrator." : "Εάν δεν το αιτηθήκατε, παρακαλούμε επικοινωνήστε με τον διαχειριστή.",
+    "%1$s changed your email address on %2$s." : "%1$sάλλαξε τη διεύθυνση ηλεκτρονικού ταχυδρομείου σε %2$s.",
+    "Your email address on %s was changed." : "Η ηλεκτρονική σας διεύθυνση στο %s έχει αλλάξει.",
+    "Your email address on %s was changed by an administrator." : "Η διεύθυνση ηλεκτρονικής αλληλογραφίας στο %s άλλαξε από τον διαχειριστή.",
+    "Email address for %1$s changed on %2$s" : "Η διεύθυνση ηλεκτρονικού ταχυδρομείου για το %1$s άλλαξε σε %2$s",
+    "Email address changed for %s" : "Το συνθηματικό άλλαξε για τον %s",
+    "The new email address is %s" : "Η νέα διεύθυνση ηλεκτρονικής αλληλογραφίας είναι %s",
+    "Your %s account was created" : "Ο λογαριασμός %s δημιουργήθηκε",
+    "Welcome aboard" : "Καλώς ήλθατε",
+    "Welcome aboard %s" : "Καλώς ήλθατε %s",
+    "Your username is: %s" : "Το όνομα χρήστη σας είναι: %s",
+    "Set your password" : "Καθορισμός συνθηματικού",
+    "Go to %s" : "Πηγαίνετε στο %s",
+    "Install Client" : "Εγκατάσταση πελάτη",
+    "Password confirmation is required" : "Απαιτείται επιβεβαίωση συνθηματικού",
     "Couldn't remove app." : "Αδυναμία αφαίρεσης εφαρμογής.",
-    "Admins can't remove themself from the admin group" : "Οι διαχειριστές δεν μπορούν να αφαιρέσουν τους εαυτούς τους από την ομάδα των διαχειριστών",
-    "Unable to add user to group %s" : "Αδυναμία προσθήκη χρήστη στην ομάδα %s",
-    "Unable to remove user from group %s" : "Αδυναμία αφαίρεσης χρήστη από την ομάδα %s",
     "Couldn't update app." : "Αδυναμία ενημέρωσης εφαρμογής",
-    "Add trusted domain" : "Προσθέστε αξιόπιστη περιοχή",
     "Migration in progress. Please wait until the migration is finished" : "Μετάβαση σε εξέλιξη. Παρακαλούμε περιμένετε μέχρι να ολοκληρωθεί η μετάβαση",
     "Migration started …" : "Η μετάβαση ξεκίνησε ...",
     "Not saved" : "Δεν αποθηκεύτηκε",
-    "Sending..." : "Αποστέλεται...",
+    "Sending…" : "Γινεται αποστολή...",
+    "Email sent" : "Το Email απεστάλη ",
     "Official" : "Επίσημο",
     "All" : "Όλες",
     "Update to %s" : "Ενημέρωση σε %s",
     "No apps found for your version" : "Δεν βρέθηκαν εφαρμογές για αυτή την έκδοση",
+    "The app will be downloaded from the app store" : "Αυτή η εφαρμογή θα ",
+    "Official apps are developed by and within the community. They offer central functionality and are ready for production use." : "Οι επίσημες εφαρμογές αναπτύσσονται μέσα από την κοινότητα. Προσφέρουν κεντρική λειτουργικότητα και είναι έτοιμες για παραγωγική χρήση. ",
     "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Οι εγκεκριμένες εφαρμογές αναπτύχθηκαν από αξιόπιστους προγραμματιστές και έχουν περάσει έναν συνοπτικό έλεγχο ασφαλείας. Διατηρούνται ενεργά σε ένα αποθετήριο ανοιχτού κώδικα και οι συντηρητές θεωρούν οτι είναι σταθερές για κανονική χρήση.",
     "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "Η εφαρμογή αυτή δεν ελέγχεται για θέματα ασφάλειας και είναι νέα ή είναι γνωστό ότι είναι ασταθής. Η εγκατάσταση γίνεται με δική σας ευθύνη.",
-    "Please wait...." : "Παρακαλώ περιμένετε...",
+    "Disabling app …" : "Γίνεται απενεργοποίηση εφαρμογής...",
     "Error while disabling app" : "Σφάλμα κατά την απενεργοποίηση εισόδου",
     "Disable" : "Απενεργοποίηση",
     "Enable" : "Ενεργοποίηση",
+    "Enabling app …" : "Γίνεται ενεργοποίηση εφαρμογής...",
     "Error while enabling app" : "Σφάλμα κατά την ενεργοποίηση της εφαρμογής",
-    "Error: this app cannot be enabled because it makes the server unstable" : "Σφάλμα: αυτή η εφαρμογή δεν μπορεί να ενεργοποιηθεί γιατί θα καταστήσει ασταθή τον διακομιστή.",
-    "Error: could not disable broken app" : "Σφάλμα: αδυναμία απενεργοποίησης κατεστραμμένης εφαρμογής",
+    "Error: Could not disable broken app" : "Σφάλμα: αδυναμία απενεργοποίησης κατεστραμμένης εφαρμογής",
     "Error while disabling broken app" : "Σφάλμα κατά την απενεργοποίηση κατεστραμμένης εφαρμογής",
-    "Updating...." : "Ενημέρωση...",
-    "Error while updating app" : "Σφάλμα κατά την ενημέρωση της εφαρμογής",
+    "App up to date" : "Ενημερωμένη εφαρμογή",
     "Updated" : "Ενημερώθηκε",
-    "Uninstalling ...." : "Απεγκατάσταση ....",
-    "Error while uninstalling app" : "Σφάλμα κατά την απεγκατάσταση της εφαρμογής",
-    "Uninstall" : "Απεγκατάσταση",
-    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Η εφαρμογή έχει ενεργοποιηθεί αλλά χρειάζεται ενημέρωση. Θα μεταφερθείτε στη σελίδα ενημέρωσης σε 5 δευτερόλεπτα.",
-    "App update" : "Ενημέρωση εφαρμογής",
+    "Removing …" : "Αφαίρεση ...",
+    "Remove" : "Αφαίρεση",
     "Approved" : "Εγκεκριμένο",
     "Experimental" : "Πειραματικό",
     "No apps found for {query}" : "Δεν βρέθηκαν εφαρμογές για {query}",
+    "Enable all" : "Ενεργοποίηση όλων",
     "Disconnect" : "Αποσύνδεση",
+    "Revoke" : "Ανάκληση",
     "Internet Explorer" : "Internet Explorer",
     "Edge" : "Edge",
     "Firefox" : "Firefox",
     "Google Chrome" : "Google Chrome",
     "Safari" : "Safari",
     "Google Chrome for Android" : "Google Chrome για Android",
+    "iPhone iOS" : "iPhone iOS",
+    "iPad iOS" : "iPad iOS",
     "iOS Client" : "Πελάτης iOS",
     "Android Client" : "Πελάτης Android",
+    "Sync client - {os}" : "Συγχρονισμός πελατών - {os}",
     "This session" : "Αυτή η συνεδρία",
+    "Copy" : "Αντιγραφή",
     "Copied!" : "Αντιγράφτηκε!",
     "Not supported!" : "Δεν υποστηρίζονται!",
     "Press ⌘-C to copy." : "Για αντιγραφή πατήστε ⌘-C.",
@@ -90,6 +130,16 @@ OC.L10N.register(
     "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Προέκυψε σφάλμα. Παρακαλούμε μεταφορτώστε ένα πιστοποιητικό PEM κωδικοποιημένο κατά ASCII.",
     "Valid until {date}" : "Έγκυρο έως {date}",
     "Delete" : "Διαγραφή",
+    "Local" : "Τοπικά",
+    "Private" : "Ιδιωτικά",
+    "Only visible to local users" : "Εμφανές μόνο σε τοπικούς χρήστες",
+    "Only visible to you" : "Εμφανές μόνο σε εσάς",
+    "Contacts" : "Επαφές",
+    "Visible to local users and to trusted servers" : "Προσθήκη στη λίστα των έμπιστων διακομιστών",
+    "Public" : "Δημόσιο",
+    "Will be synced to a global and public address book" : "Θα συγχρονιστεί με παγκόσμιο και δημόσιο βιβλίο διευθύνσεων",
+    "Verify" : "Επαλήθευση",
+    "Verifying …" : "Γίνεται επαλήθευση ...",
     "Select a profile picture" : "Επιλογή εικόνας προφίλ",
     "Very weak password" : "Πολύ αδύναμο συνθηματικό",
     "Weak password" : "Αδύναμο συνθηματικό",
@@ -102,29 +152,57 @@ OC.L10N.register(
     "A valid group name must be provided" : "Πρέπει να δοθεί ένα έγκυρο όνομα ομάδας",
     "deleted {groupName}" : "διαγραφή {groupName}",
     "undo" : "αναίρεση",
+    "{size} used" : "{μέγεθος} που χρησιμοποιείται",
     "never" : "ποτέ",
     "deleted {userName}" : "διαγραφή {userName}",
+    "No user found for <strong>{pattern}</strong>" : "Δεν βρέθηκαν χρήστες για την αναζήτηση {search}",
+    "Unable to add user to group {group}" : "Αδυναμία προσθήκης χρήστη στην ομάδα {group}",
+    "Unable to remove user from group {group}" : "Αδυναμία αφαίρεσης χρήστη από την ομάδα {group}",
     "Add group" : "Προσθήκη ομάδας",
     "no group" : "καμια ομάδα",
     "Password successfully changed" : "Το συνθηματικό αλλάχτηκε επιτυχώς",
     "Changing the password will result in data loss, because data recovery is not available for this user" : "Η αλλαγή του κωδικού πρόσβασης θα έχει ως αποτέλεσμα το χάσιμο δεδομένων, επειδή η ανάκτηση δεδομένων δεν είναι διαθέσιμη γι' αυτόν τον χρήστη",
+    "Could not change the users email" : "Αδυναμία αλλαγής της ηλεκτρονικής διεύθυνσης του χρήστη",
+    "Error while changing status of {user}" : "Σφάλμα κατά την αλλαγή κατάστασης του {χρήστη}",
     "A valid username must be provided" : "Πρέπει να δοθεί έγκυρο όνομα χρήστη",
     "Error creating user: {message}" : "Σφάλμα δημιουργίας χρήστη: {message}",
-    "A valid password must be provided" : "Πρέπει να δοθεί έγκυρο συνθηματικό",
-    "A valid email must be provided" : "Πρέπει να εισαχθεί ένα έγκυρο email",
-    "__language_name__" : "Ελληνικά",
-    "Unlimited" : "Απεριόριστο",
-    "Personal info" : "Προσωπικές Πληροφορίες",
-    "Sessions" : "Συνεδρίες",
-    "App passwords" : "Συνθηματικά εφαρμογής",
-    "Sync clients" : "Συγχρονισμός πελατών",
+    "Developer documentation" : "Τεκμηρίωση προγραμματιστή",
+    "View in store" : "Προβολή στο κέντρο εφαρμογών",
+    "Limit to groups" : "Όριο στις ομάδες",
+    "by %s" : "από %s",
+    "%s-licensed" : "%s-αδειοδοτημένο",
+    "Documentation:" : "Τεκμηρίωση:",
+    "User documentation" : "Τεκμηρίωση Χρήστη",
+    "Admin documentation" : "Τεκμηρίωση Διαχειριστή",
+    "Visit website" : "Επισκεφθείτε την ιστοσελίδα",
+    "Report a bug" : "Αναφέρετε σφάλμα",
+    "Show description …" : "Εμφάνιση περιγραφής",
+    "Hide description …" : "Απόκρυψη περιγραφής",
+    "This app has an update available." : "Αυτή η εφαρμογή έχει διαθέσιμη ενημέρωση.",
+    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Αυτή η εφαρμογή δεν έχει ελάχιστη έκδοση του Nextcloud ανατεθειμένη. Αυτό θα αποτελεί σφάλμα στο μέλλον.",
+    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Αυτή η εφαρμογή δεν έχει μέγιστη έκδοση του Nextcloud ανατεθειμένη. Αυτό θα αποτελεί σφάλμα στο μέλλον.",
+    "This app cannot be installed because the following dependencies are not fulfilled:" : "Αυτή η εφαρμογή δεν μπορεί να εγκατασταθεί διότι δεν εκπληρώνονται οι ακόλουθες εξαρτήσεις:",
+    "Enable only for specific groups" : "Ενεργοποίηση μόνο για καθορισμένες ομάδες",
+    "SSL Root Certificates" : "Πιστοποιητικά SSL του Root",
+    "Common Name" : "Κοινό Όνομα",
+    "Valid until" : "Έγκυρο έως",
+    "Issued By" : "Έκδόθηκε από",
+    "Valid until %s" : "Έγκυρο έως %s",
+    "Import root certificate" : "Εισαγωγή Πιστοποιητικού Root",
+    "Administrator documentation" : "Τεκμηρίωση Διαχειριστή",
+    "Online documentation" : "Τεκμηρίωση στο Διαδίκτυο",
+    "Forum" : "Φόρουμ",
+    "Getting help" : "Λήψη βοήθειας",
+    "Commercial support" : "Εμπορική Υποστήριξη",
     "None" : "Τίποτα",
     "Login" : "Σύνδεση",
     "Plain" : "Απλό",
     "NT LAN Manager" : "Διαχειριστης NT LAN",
+    "SSL/TLS" : "SSL/TLS",
+    "STARTTLS" : "STARTTLS",
     "Email server" : "Διακομιστής Email",
-    "Open documentation" : "Ανοιχτή τεκμηρίωση.",
-    "This is used for sending out notifications." : "Χρησιμοποιείται για αποστολή ειδοποιήσεων.",
+    "Open documentation" : "Άνοιγμα τεκμηρίωσης.",
+    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Είναι σημαντικό ",
     "Send mode" : "Κατάσταση αποστολής",
     "Encryption" : "Κρυπτογράφηση",
     "From address" : "Από τη διεύθυνση",
@@ -153,30 +231,23 @@ OC.L10N.register(
     "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Πρέπει να μεταφέρετε τα κλειδιά σας κρυπτογράφησης από την παλιά κρυπτογράφηση (ownCloud <= 8.0) στην καινούρια.",
     "Start migration" : "Έναρξη μετάβασης",
     "Security & setup warnings" : "Προειδοποιήσεις ασφάλειας & ρυθμίσεων",
-    "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "Η php δεν φαίνεται να είναι σωστά ρυθμισμένη για ερωτήματα σε μεταβλητές περιβάλλοντος του συστήματος. Η δοκιμή με την εντολή getenv(\"PATH\") επιστρέφει κενή απάντηση.",
-    "Please check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm." : "Παρακαλούμε ελέγξτε την <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">τεκμηρίωση εγκατάστασης ↗</a> για τις σημειώσεις ρυθμίσεων php και για τις ρυθμίσεις της php του διακομιστή, ειδικότερα όταν χρησιμοποιείτε το php-fpm.",
     "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Η ρύθμιση  \"μόνο ανάγνωση\"  έχει ενεργοποιηθεί. Αυτό εμποδίζει τον καθορισμό κάποιων ρυθμίσεων μέσω της διεπαφής web. Επιπλέον, το αρχείο πρέπει να γίνει χειροκίνητα εγγράψιμο πριν από κάθε διαδικασία ενημέρωσης.",
-    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "Ο PHP φαίνεται να είναι ρυθμισμένος ώστε να αφαιρεί μπλοκ εσωτερικών κειμένων (inline doc). Αυτό θα καταστήσει κύριες εφαρμογές μη-διαθέσιμες.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Αυτό πιθανόν προκλήθηκε από προσωρινή μνήμη (cache)/επιταχυντή όπως τη Zend OPcache ή τον eAccelerator.",
-    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "Η PHP ενοτητα 'fileinfo' λειπει. Σας συνιστούμε να ενεργοποιήσετε αυτή την ενότητα για να έχετε καλύτερα αποτελέσματα με τον εντοπισμό τύπου MIME. ",
     "System locale can not be set to a one which supports UTF-8." : "Οι ρυθμίσεις τοποθεσίας συστήματος δεν μπορούν να οριστούν σε κάποιες που δεν υποστηρίζουν UTF-8.",
-    "This means that there might be problems with certain characters in file names." : "Αυτό σημαίνει ότι μπορεί να υπάρχουν προβλήματα με κάποιους χαρακτήρες στα ονόματα αρχείων.",
-    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Προτείνουμε ανεπιφύλακτα να εγκαταστήσετε  στο σύστημά σας τα απαιτούμενα πακέτα έτσι ώστε να υποστηρίζεται μια από τις ακόλουθες ρυθμίσεις τοποθεσίας: %s.",
-    "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Αν η εγκατάστασή σας δεν έχει γίνει στο root του τομέα  και χρησιμοποιείται το cron του συστήματος, μπορεί να υπάρξουν ζητήματα με τη δημιουργία URL. Για να αποφύγετε αυτά τα προβλήματα, παρακαλώ ρυθμίστε την επιλογή  \"overwrite.cli.url\" στο αρχείο  config.php που βρίσκεται στη διαδρομή webroot της εγκατάστασής σας (Suggested: \"%s\")",
-    "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "Δεν ήταν δυνατή η εκτέλεση της cronjob μέσω τερματικού. Εμφανίστηκαν τα παρακάτω τεχνικά σφάλματα:",
     "All checks passed." : "Όλοι οι έλεγχοι επιτυχείς.",
-    "Cron" : "Cron",
-    "Last cron job execution: %s." : "Τελευταία εκτέλεση cron job: %s.",
-    "Last cron job execution: %s. Something seems wrong." : "Τελευταία εκτέλεση cron job: %s. Κάτι πήγε στραβά.",
-    "Cron was not executed yet!" : "Η διεργασία cron δεν έχει εκτελεστεί ακόμα!",
+    "Background jobs" : "Εργασίες παρασκηνίου",
     "Execute one task with each page loaded" : "Εκτελεί μια διεργασία κάθε φορά που φορτώνεται μια σελίδα",
-    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "Το cron.php είναι καταχωρημένο σε μια υπηρεσία webcron ώστε να καλεί το cron.php κάθε 15 λεπτά μέσω http.",
-    "Use system's cron service to call the cron.php file every 15 minutes." : "Χρησιμοποιήστε την cron υπηρεσία του συτήματος για να καλέσετε το cron.php αρχείο κάθε 15 λεπτά.",
+    "cron.php is registered at a webcron service to call cron.php every 15 minutes over HTTP." : "Το cron.php είναι καταχωρημένο σε μια υπηρεσία webcron ώστε να καλεί το cron.php κάθε 15 λεπτά μέσω HTTP.",
+    "Use system cron service to call the cron.php file every 15 minutes." : "Χρησιμοποιήστε την cron υπηρεσία του συστήματος για να καλέσετε το cron.php αρχείο κάθε 15 λεπτά.",
+    "The cron.php needs to be executed by the system user \"%s\"." : "Το cron.php πρέπει να εκτελεστεί από τον χρήστη του συστήματος \"%s\".",
+    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Για να τρέξετε αυτό χρειάζεστε την επέκταση PHP POSIX. Δείτε {linkstart} PHP τεκμηρίωση {linked} για περισσότερες λεπτομέρειες.",
     "Version" : "Έκδοση",
     "Sharing" : "Διαμοιρασμός",
+    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Ως διαχειριστής μπορείτε να ρυθμίσετε λεπτομερώς την συμπεριφορά διαμοιρασμού.\nΠαρακαλούμε ανατρέξτε στην τεκμηρίωση για περισσότερες πληροφορίες.",
     "Allow apps to use the Share API" : "Επιτρέπει την χρήση του API διαμοιρασμού σε εφαρμογές ",
     "Allow users to share via link" : "Να επιτρέπεται σε χρήστες ο διαμοιρασμός μέσω συνδέσμου",
     "Allow public uploads" : "Επιτρέπεται το κοινόχρηστο ανέβασμα",
+    "Always ask for a password" : "Ερώτηση συνθηματικού πάντα",
     "Enforce password protection" : "Επιβολή προστασίας με κωδικό",
     "Set default expiration date" : "Ορισμός ερήμην ημερομηνίας λήξης",
     "Expire after " : "Λήξη μετά από",
@@ -187,38 +258,16 @@ OC.L10N.register(
     "Restrict users to only share with users in their groups" : "Να επιτρέπεται σε χρήστες ο διαμοιρασμός μόνο με χρήστες που ανήκουν στις ομάδες τους",
     "Exclude groups from sharing" : "Εξαίρεση ομάδων από τον διαμοιρασμό",
     "These groups will still be able to receive shares, but not to initiate them." : "Αυτές οι ομάδες θα συνεχίσουν να λαμβάνουν διαμοιρασμούς, αλλά δεν θα είναι δυνατό να τους δημιουργήσουν.",
-    "Allow username autocompletion in share dialog. If this is disabled the full username needs to be entered." : "Να επιτρέπεται η χρήση αυτόματης συμπλήρωσης στο διάλογο διαμοιρασμού. Αν αυτό είναι απενεργοποιημένο θα πρέπει να εισαχθεί το πλήρες όνομα χρήστη.",
+    "This text will be shown on the public link upload page when the file list is hidden." : "Αυτό το κείμενο θα ",
     "Tips & tricks" : "Συμβουλές & τεχνάσματα",
     "How to do backups" : "Πώς να κάνετε αντίγραφα ασφαλείας",
-    "Advanced monitoring" : "Παρακολούθηση για προχωρημένους",
     "Performance tuning" : "Ρύθμιση βελτίωσης της απόδοσης",
     "Improving the config.php" : "Βελτίωση του  config.php",
     "Theming" : "Θέματα",
+    "Check the security of your Nextcloud over our security scan" : "Ελέγξτε την ασφάλεια του Nextcloud σας μέσω της σάρωσης ασφαλείας",
     "Hardening and security guidance" : "Οδηγίες ασφάλειας και θωράκισης",
-    "Developer documentation" : "Τεκμηρίωση προγραμματιστή",
-    "Documentation:" : "Τεκμηρίωση:",
-    "User documentation" : "Τεκμηρίωση Χρήστη",
-    "Admin documentation" : "Τεκμηρίωση Διαχειριστή",
-    "Visit website" : "Επισκεφθείτε την ιστοσελίδα",
-    "Report a bug" : "Αναφέρετε σφάλμα",
-    "Show description …" : "Εμφάνιση περιγραφής",
-    "Hide description …" : "Απόκρυψη περιγραφής",
-    "This app has an update available." : "Αυτή η εφαρμογή έχει διαθέσιμη ενημέρωση.",
-    "This app cannot be installed because the following dependencies are not fulfilled:" : "Αυτή η εφαρμογή δεν μπορεί να εγκατασταθεί διότι δεν εκπληρώνονται οι ακόλουθες εξαρτήσεις:",
-    "Enable only for specific groups" : "Ενεργοποίηση μόνο για καθορισμένες ομάδες",
-    "Uninstall App" : "Απεγκατάσταση Εφαρμογής",
-    "SSL Root Certificates" : "Πιστοποιητικά SSL του Root",
-    "Common Name" : "Κοινό Όνομα",
-    "Valid until" : "Έγκυρο έως",
-    "Issued By" : "Έκδόθηκε από",
-    "Valid until %s" : "Έγκυρο έως %s",
-    "Import root certificate" : "Εισαγωγή Πιστοποιητικού Root",
-    "Cheers!" : "Χαιρετισμούς!",
-    "Administrator documentation" : "Τεκμηρίωση Διαχειριστή",
-    "Online documentation" : "Τεκμηρίωση στο Διαδίκτυο",
-    "Forum" : "Φόρουμ",
-    "Commercial support" : "Εμπορική Υποστήριξη",
     "You are using <strong>%s</strong> of <strong>%s</strong>" : "Χρησιμοποιείτε <strong>%s</strong> από <strong>%s</strong>",
+    "You are using <strong>%s</strong> of <strong>%s</strong> (<strong>%s %%</strong>)" : "Χρησιμοποιείτε <strong>%s</strong> του <strong>%s</strong>(<strong>%s%%</strong>)",
     "Profile picture" : "Φωτογραφία προφίλ",
     "Upload new" : "Μεταφόρτωση νέου",
     "Select from Files" : "Επιλογή από τα Αρχεία",
@@ -227,100 +276,89 @@ OC.L10N.register(
     "Picture provided by original account" : "Φωτογραφία που παρέχεται από τον πρωτότυπο λογαριασμό",
     "Cancel" : "Άκυρο",
     "Choose as profile picture" : "Επιλέξτε εικόνα προφίλ",
+    "You are member of the following groups:" : "Είστε μέλος των ακόλουθων ομάδων:",
     "Full name" : "Πλήρες όνομα",
     "No display name set" : "Δεν ορίστηκε όνομα",
     "Email" : "Ηλεκτρονικό ταχυδρομείο",
     "Your email address" : "Η διεύθυνση ηλ. ταχυδρομείου σας",
     "No email address set" : "Δεν ορίστηκε διεύθυνση email",
-    "For password recovery and notifications" : "Η ανάκτηση του συνθηματικού και οι ειδοποιήσεις",
-    "You are member of the following groups:" : "Είστε μέλος των ακόλουθων ομάδων:",
+    "For password reset and notifications" : "Για ανάκτηση συνθηματικού και ειδοποιήσεις",
+    "Phone number" : "Αριθμός τηλεφώνου",
+    "Your phone number" : "Ο αριθμός τηλεφώνου σας",
+    "Address" : "Διεύθυνση",
+    "Your postal address" : "Ο ταχυδρομικός σας κώδικας",
+    "Website" : "Ιστοσελίδα",
+    "It can take up to 24 hours before the account is displayed as verified." : "Η επαλήθευση του λογαριασμού μπορεί να διαρκέσει έως και 24 ώρες.",
+    "Link https://…" : "Σύνδεσμος https://…",
+    "Twitter" : "Twitter",
+    "Language" : "Γλώσσα",
+    "Help translate" : "Βοηθήστε στη μετάφραση",
     "Password" : "Συνθηματικό",
     "Current password" : "Τρέχων συνθηματικό",
     "New password" : "Νέο συνθηματικό",
     "Change password" : "Αλλαγή συνθηματικού",
-    "Language" : "Γλώσσα",
-    "Help translate" : "Βοηθήστε στη μετάφραση",
-    "Get the apps to sync your files" : "Λήψη της εφαρμογής για συγχρονισμό των αρχείων σας",
-    "Desktop client" : "Πελάτης σταθερού υπολογιστή",
-    "Android app" : "Εφαρμογή Android",
-    "iOS app" : "Εφαρμογή iOS",
-    "Show First Run Wizard again" : "Προβολή Οδηγού Πρώτης Εκτέλεσης ξανά",
+    "Web, desktop and mobile clients currently logged in to your account." : " ",
     "Device" : "Συσκευή",
     "Last activity" : "Τελευταία δραστηριότητα",
-    "Name" : "Όνομα",
     "App name" : "Όνομα εφαρμογής",
     "Create new app password" : "Δημιουργία νέου συνθηματικού εφαρμογής",
+    "Use the credentials below to configure your app or device." : "Χρησιμοποιήστε τα παρακάτω διαπιστευτήρια για να ρυθμίσετε την εφαρμογή ή την συσκευή σας.",
     "For security reasons this password will only be shown once." : "Για λόγους ασφαλείας αυτό το συνθηματικό θα εμφανιστεί μόνο μια φορά.",
     "Username" : "Όνομα χρήστη",
     "Done" : "Ολοκληρώθηκε",
-    "Follow us on Google Plus!" : "Ακολουθήστε μας στο Google Plus!",
-    "Like our facebook page!" : "Ακολουθήστε μας στην σελίδα μας στο facebook!",
-    "Subscribe to our twitter channel!" : "Εγγραφείτε στο κανάλι μας στο twitter!",
-    "Subscribe to our news feed!" : "Εγγραφείτε στην ροή των νέων μας!",
+    "Follow us on Google+" : "Ακολουθήστε μας στο Google+",
+    "Like our Facebook page" : "Ακολουθήστε μας στην σελίδα μας στο facebook!",
+    "Follow us on Twitter" : "Ακολουθήστε μας στο Twitter",
+    "Check out our blog" : "Επισκεφθείτε το ιστολόγιό μας!",
+    "Subscribe to our newsletter" : "Εγγραφείτε στο ενημερωτικό δελτίο μας!",
+    "Settings" : "Ρυθμίσεις",
     "Show storage location" : "Εμφάνιση τοποθεσίας αποθήκευσης",
-    "Show last log in" : "Εμφάνιση τελευταίας εισόδου",
     "Show user backend" : "Εμφάνιση χρήστη συστήματος υποστήριξης",
-    "Send email to new user" : "Αποστολή μηνύματος στο νέο χρήστη",
-    "Show email address" : "Εμφάνιση διεύθυνσης ηλ. αλληλογραφίας",
-    "E-Mail" : "Ηλεκτρονική αλληλογραφία",
-    "Create" : "Δημιουργία",
-    "Admin Recovery Password" : "Κωδικός Επαναφοράς Διαχειριστή ",
-    "Enter the recovery password in order to recover the users files during password change" : "Εισάγετε το συνθηματικό ανάκτησης ώστε να ανακτήσετε τα αρχεία χρηστών κατά την αλλαγή συνθηματικού",
+    "Show last login" : "Εμφάνιση τελευταιας σύνδεσης",
+    "Add user" : "Προσθήκη χρήστη",
     "Everyone" : "Όλοι",
     "Admins" : "Διαχειριστές",
+    "Disabled" : "Απενεργοποιημένο",
     "Default quota" : "Προεπιλέγμενη χωρητικότητα",
     "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Παρακαλώ εισάγετε επιτρεπόμενα μερίδια αποθηκευτικού χώρου (π.χ. \"512 MB\"  ή \"12 GB\")",
+    "Unlimited" : "Απεριόριστο",
     "Other" : "Άλλο",
+    "Group admin for" : "Ομαδα διαχειριστή για",
+    "Recovery password" : "Επαναφορά συνθηματικού",
     "Quota" : "Σύνολο Χώρου",
     "Storage location" : "Τοποθεσία αποθηκευτικού χώρου",
     "User backend" : "Σύστημα υποστήριξης χρήστη",
     "Last login" : "Τελευταία είσοδος",
+    "E-Mail" : "Ηλεκτρονική αλληλογραφία",
+    "Admin Recovery Password" : "Κωδικός Επαναφοράς Διαχειριστή ",
+    "Enter the recovery password in order to recover the users files during password change" : "Εισάγετε το συνθηματικό ανάκτησης ώστε να ανακτήσετε τα αρχεία χρηστών κατά την αλλαγή συνθηματικού",
     "change full name" : "αλλαγή πλήρους ονόματος",
     "set new password" : "επιλογή νέου κωδικού",
     "change email address" : "αλλαγή διεύθυνσης ηλ. αλληλογραφίας",
     "Default" : "Προκαθορισμένο",
-    "log-level out of allowed range" : "Το επίπεδο καταγραφής είναι εκτός του επιτρεπόμενου πεδίου",
-    "Language changed" : "Η γλώσσα άλλαξε",
-    "Are you really sure you want add \"{domain}\" as trusted domain?" : "Είστε πραγματικά σίγουροι ότι θέλετε να προσθέσετε το \"{domain}\" σαν αξιόπιστη περιοχή;",
-    "iPhone" : "iPhone",
-    "add group" : "προσθήκη ομάδας",
-    "Everything (fatal issues, errors, warnings, info, debug)" : "Όλα (καίρια ζητήματα, σφάλματα, προειδοποιήσεις, πληροφορίες, αποσφαλμάτωση)",
-    "Info, warnings, errors and fatal issues" : "Πληροφορίες, προειδοποιήσεις, σφάλματα και καίρια ζητήματα",
-    "Warnings, errors and fatal issues" : "Προειδοποιήσεις, σφάλματα και καίρια ζητήματα",
-    "Errors and fatal issues" : "Σφάλματα και καίρια ζητήματα",
-    "Fatal issues only" : "Καίρια ζητήματα μόνο",
-    "Log" : "Καταγραφές",
-    "Download logfile" : "Λήψη αρχείου ιστορικού",
-    "More" : "Περισσότερα",
-    "Less" : "Λιγότερα",
-    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "Το αρχείο ιστορικού είναι μεγαλύτερο από 100ΜΒ. Η λήψη του ίσως πάρει λίγη ώρα!",
-    "Allow users to send mail notification for shared files" : "Επιτρέψτε στους χρήστες να στέλνουν ειδοποιήσεις μέσω ηλεκτρονικού ταχυδρομείου για κοινόχρηστα αρχεία",
-    "Allow users to send mail notification for shared files to other users" : "Να επιτρέπεται η αποστολή ειδοποιήσεων σε άλλους χρήστες, μέσω αλληλογραφίας για κοινόχρηστα αρχεία",
-    "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "Ως βάση δεδομένων χρησιμοποιείται η SQLite. Για μεγαλύτερες εγκαταστάσεις συνιστούμε να επιλέξετε ένα διαφορετικό σύστημα υποστήριξης βάσης δεδομένων.",
-    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Ειδικά όταν χρησιμοποιείτε τον πελάτη για συγχρονισμό στον υπολογιστή σας, δεν συνίσταται η χρήση της SQLite.",
-    "Experimental applications ahead" : "Πειραματικές εφαρμογές",
-    "Experimental apps are not checked for security issues, new or known to be unstable and under heavy development. Installing them can cause data loss or security breaches." : "Οι πειραματικές εφαρμογές δεν ελέγχονται για θέματα ασφάλειας, είναι ασταθείς και υπό συνεχή εξέλιξη.  Η εγκατάσταση τους μπορεί να προκαλέσει απώλεια δεδομένων ή παραβιάσεις της ασφάλειας.",
-    "Enable experimental apps" : "Ενεργοποίηση πειραματικών εφαρμογών",
-    "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Χαίρεται,<br><br>απλά σας κάνουμε γνωστό ότι διαθέτετε έναν %s λογαριασμό.<br><br>Το όνομά σας είναι: %s<br>Έχετε πρόσβαση: <a href=\"%s\">%s</a><br><br>",
-    "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Χαίρεται, \nαπλά σας κάνουμε γνωστό ότι διαθέτετε έναν %s λογαριασμό.\nΤο όνομά σας είναι: %s\nΈχετε πρόσβαση: %s\n",
-    "If you want to support the project\n\t\t<a href=\"https://nextcloud.com/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">join development</a>\n\t\t<or></or>\n\t\t<a href=\"https://nextcloud.com/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">spread the word</a>!" : "Εάν θέλετε να υποστηρίξετε το έργο\n\t\t<a href=\"https://nextcloud.com/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">συνεργαστείτε με τους προγραμματιστές</a>\n\t\t<or></or>\n\t\t<a href=\"https://nextcloud.com/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">προωθήστε το</a>!",
-    "Add Group" : "Προσθήκη ομάδας",
-    "Group" : "Ομάδα",
-    "Default Quota" : "Προεπιλεγμένη χωρητικότητα",
-    "Full Name" : "Πλήρες όνομα",
-    "Storage Location" : "Τοποθεσία αποθηκευτικού χώρου",
-    "User Backend" : "Σύστημα υποστήριξης χρήστη",
-    "Last Login" : "Τελευταία είσοδος",
-    "APCu" : "APCu",
-    "Redis" : "Redis",
-    "External Storage" : "Εξωτερικό Αποθηκευτικό Μέσο",
-    "Updates" : "Ενημερώσεις",
-    "No apps found for \"{query}\"" : "Δεν βρέθηκαν εφαρμογές για \"{query}\"",
-    "An error occurred: {message}" : "Παρουσιάστηκε σφάλμα: {message}",
-    "Please check the <a target=\"_blank\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm." : "Παρακαλούμε ελέγξτε την <a target=\"_blank\" href=\"%s\">τεκμηρίωση εγκατάστασης ↗</a> για τις σημειώσεις ρυθμίσεων php και για τις ρυθμίσεις της php του διακομιστή, ειδικότερα όταν χρησιμοποιείτε το php-fpm.",
-    "Your server is running on Microsoft Windows. We highly recommend Linux for optimal user experience." : "Ο διακομιστής σας εκτελείται σε Microsoft Windows. Σας συνιστούμε το Linux για μια βέλτιστη εμπειρία χρήστη.",
-    "Please double check the <a target=\"_blank\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "Παρακαλώ ελέγξτε διπλά τα <a target=\"_blank\" href=\"%s\">εγχειρίδια εγκατάστασης ↗</a>, και ελέγξτε για σφάλματα ή προειδοποιήσεις στο <a href=\"#log-section\">ιστορικό</a>.",
-    "Encryption alone does not guarantee security of the system. Please see Nextcloud documentation for more information about how the encryption app works, and the supported use cases." : "Μονάχα η κρυπτογράφηση δεν σας εγγυάται την ασφάλεια του συστήματος. Παρακαλώ δείτε στην τεκμηρίωση του Nextcloud για περισσότερες πληροφορίες σχετικά με τον τρόπο που δουλεύει η εφαρμογή κρυπτογράφησης, και τις υποστηριζόμενες περιπτώσεις.",
-    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" href=\"%s\">documentation ↗</a>." : "Για να μεταφερθείτε σε άλλη βάση δεδομένων χρησιμοποιήστε το εργαλείο της γραμμής εντολών: 'occ db:convert-type', ή δείτε στην <a target=\"_blank\" href=\"%s\">τεκμηρίωση ↗</a>."
+    "A problem occurred, please check your log files (Error: %s)" : "Παρουσιάστηκε πρόβλημα, παρακαλώ ελέγξτε τα αρχεία καταγραφής σας (Σφάλμα: %s)",
+    "Migration Completed" : "Η μετάβαση ολοκληρώθηκε",
+    "Are you really sure you want add {domain} as trusted domain?" : "Θέλετε σίγουρα να προσθέσετε τον τομέα {domain} ως έμπιστο τομέα;",
+    "Add trusted domain" : "Προσθέστε αξιόπιστη περιοχή",
+    "Updating...." : "Γίνεται ενημέρωση....",
+    "Error while updating app" : "Σφάλμα κατά την ενημέρωση της εφαρμογής",
+    "A valid password must be provided" : "Πρέπει να δοθεί έγκυρο συνθηματικό",
+    "A valid email must be provided" : "Πρέπει να εισαχθεί ένα έγκυρο email",
+    "__language_name__" : "Ελληνικά",
+    "Personal info" : "Προσωπικές Πληροφορίες",
+    "Sync clients" : "Συγχρονισμός πελατών",
+    "Desktop client" : "Πελάτης σταθερού υπολογιστή",
+    "Android app" : "Εφαρμογή Android",
+    "iOS app" : "Εφαρμογή iOS",
+    "App passwords" : "Συνθηματικά εφαρμογής",
+    "Follow us on Google+!" : "Ακολουθήστε μας στο Google+!",
+    "Like our facebook page!" : "Ακολουθήστε μας στην σελίδα μας στο facebook!",
+    "Follow us on Twitter!" : "Ακολουθήστε μας στο Twitter!",
+    "Check out our blog!" : "Επισκεφθείτε το ιστολόγιό μας!",
+    "Subscribe to our newsletter!" : "Εγγραφείτε στο ενημερωτικό δελτίο μας!",
+    "Show email address" : "Εμφάνιση διεύθυνσης ηλ. αλληλογραφίας",
+    "Send email to new user" : "Αποστολή μηνύματος στο νέο χρήστη",
+    "Create" : "Δημιουργία",
+    "Group name" : "Όνομα ομάδας"
 },
 "nplurals=2; plural=(n != 1);");
