@@ -5,8 +5,10 @@ OC.L10N.register(
     "You changed your email address" : "Ți-ai schimbat adresa de email",
     "Your email address was changed by an administrator" : "Adresa ta de email a fost modificată de un administrator",
     "Security" : "Securitate",
-    "Couldn't remove app." : "Nu s-a putut înlătura aplicația.",
-    "Couldn't update app." : "Aplicaţia nu s-a putut actualiza.",
+    "Your apps" : "Aplicațiile tale",
+    "Updates" : "Actualizări",
+    "Enabled apps" : "Aplicații active",
+    "Disabled apps" : "Aplicații inactive",
     "Wrong password" : "Parolă greșită",
     "Saved" : "Salvat",
     "No user supplied" : "Nu a fost furnizat niciun utilizator",
@@ -14,23 +16,51 @@ OC.L10N.register(
     "Authentication error" : "Eroare la autentificare",
     "Wrong admin recovery password. Please check the password and try again." : "Parolă administrativă de recuperare greșită. Verifică parola și încearcă din nou.",
     "Federated Cloud Sharing" : "Partajare federalizata cloud",
+    "Group already exists." : "Grupul există deja.",
+    "Unable to add group." : "Nu se poate adăuga grupul.",
+    "Unable to delete group." : "Nu se poate șterge grupul.",
     "Invalid SMTP password." : "Parolă SMTP invalidă.",
     "Email setting test" : "Test setări email",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : " A apărut o problemă la trimiterea emailului. Verifică-ți setărie. (Eroare: %s)",
     "You need to set your user email before being able to send test emails." : "Trebuie să îți setezi emailul de utilizator înainte de a putea să trimiți emailuri.",
     "Invalid mail address" : "Adresa mail invalidă",
+    "No valid group selected" : "Niciun grup valid selectat",
+    "A user with that name already exists." : "Există deja un utilizator cu acest nume.",
+    "Unable to create user." : "Imposibil de creat utilizatorul.",
+    "Unable to delete user." : "Imposibil de șters utilizatorul.",
+    "Error while enabling user." : "Eroare în timpul activării utilizatorului.",
+    "Error while disabling user." : "Eroare în timpul dezactivării utilizatorului.",
     "Unable to change full name" : "Nu s-a putut schimba numele complet",
+    "Your full name has been changed." : "Numele tău complet a fost schimbat.",
+    "Forbidden" : "Interzis",
+    "Invalid user" : "Utilizator invalid",
+    "Unable to change mail address" : "Nu s-a putut schimba adresa email",
+    "Email saved" : "E-mail salvat",
     "Email address changed for %s" : "Adresa de email schimbată în %s",
     "The new email address is %s" : "Adresa de email nouă este%s",
     "Your %s account was created" : "Contul tău %s a fost creat",
     "Your username is: %s" : "Utilizatorul tău este: %s",
     "Set your password" : "Setează parola",
     "Install Client" : "Instalează client",
+    "Password confirmation is required" : "Confirmarea parolei este necesară",
+    "Couldn't remove app." : "Nu s-a putut înlătura aplicația.",
+    "Couldn't update app." : "Aplicaţia nu s-a putut actualiza.",
     "Migration in progress. Please wait until the migration is finished" : "Migrare în progres. Așteaptă până când migrarea este finalizată",
     "Migration started …" : "Migrarea a început...",
     "Not saved" : "Nu a fost salvat",
     "Sending…" : "Se trimite...",
     "Email sent" : "Mesajul a fost expediat",
+    "Official" : "Oficial",
+    "All" : "Toate ",
+    "No apps found for your version" : "Nu au fost găsite aplicații pentru versiunea ta",
+    "The app will be downloaded from the app store" : "Aplicația va fi descărcată din magazin",
+    "Error while disabling app" : "Eroare în timpul dezactivării aplicației",
+    "Disable" : "Dezactivați",
+    "Enable" : "Activare",
+    "Error while enabling app" : "Eroare în timpul activării applicației",
+    "Updated" : "Actualizat",
+    "Approved" : "Aprobat",
+    "Experimental" : "Experimental",
     "Disconnect" : "Deconectare",
     "Edge" : "Edge",
     "Firefox" : "Firefox",
@@ -51,27 +81,39 @@ OC.L10N.register(
     "Contacts" : "Contacte",
     "Verify" : "Verifică",
     "Verifying …" : "Se verifică ...",
+    "Select a profile picture" : "Selectează o imagine de profil",
     "Very weak password" : "Parolă foarte slabă",
     "Weak password" : "Parolă slabă",
     "So-so password" : "Parolă medie",
     "Good password" : "Parolă bună",
     "Strong password" : "Parolă puternică",
-    "Select a profile picture" : "Selectează o imagine de profil",
     "Groups" : "Grupuri",
-    "Official" : "Oficial",
-    "User documentation" : "Documentație utilizator",
+    "Unable to delete {objName}" : "Nu s-a putut șterge {objName}",
+    "Error creating group: {message}" : "Eroare la crearea grupului: {message}",
+    "A valid group name must be provided" : "Trebuie furnizat un nume de grup valid",
+    "deleted {groupName}" : "{groupName} s-a șters",
+    "undo" : "Anulează ultima acțiune",
+    "{size} used" : "{size} folosită",
+    "never" : "niciodată",
+    "deleted {userName}" : "{userName} șters",
+    "Add group" : "Adaugă grup",
+    "Invalid quota value \"{val}\"" : "Valoare cotă invalidă \"{val}\"",
+    "no group" : "niciun grup",
+    "Password successfully changed" : "Parola a fost modificată cu succes.",
+    "Changing the password will result in data loss, because data recovery is not available for this user" : "Schimbarea parolei va rezulta în pierderea datelor deoarece recuperarea acestora nu este disponibilă pentru acest utilizator",
+    "A valid username must be provided" : "Trebuie să furnizaţi un nume de utilizator valid",
+    "Error creating user: {message}" : "Eroare la crearea utilizatorului: {message}",
     "Developer documentation" : "Documentație pentru dezvoltatori",
-    "Enable" : "Activare",
-    "The app will be downloaded from the app store" : "Aplicația va fi descărcată din magazin",
-    "Settings" : "Setări",
-    "Email" : "Email",
-    "Language" : "Limba",
-    "Unlimited" : "Nelimitată",
-    "Your apps" : "Aplicațiile tale",
-    "Disabled apps" : "Aplicații inactive",
-    "Updates" : "Actualizări",
-    "Admins" : "Administratori",
-    "Everyone" : "Toți",
+    "by %s" : "de %s",
+    "%s-licensed" : "%s-licențiat",
+    "Documentation:" : "Documentație:",
+    "User documentation" : "Documentație utilizator",
+    "Admin documentation" : "Documentație pentru administrare",
+    "Report a bug" : "Raportează un defect",
+    "Show description …" : "Arată descriere ...",
+    "Hide description …" : "Ascunde descriere ...",
+    "This app has an update available." : "Este disponibilă o actualizare pentru această aplicație.",
+    "Enable only for specific groups" : "Activează doar pentru grupuri specifice",
     "SSL Root Certificates" : "Certificate SSL rădăcină",
     "Common Name" : "Nume comun",
     "Valid until" : "Valabil până la",
@@ -79,7 +121,9 @@ OC.L10N.register(
     "Valid until %s" : "Valabil până la %s",
     "Import root certificate" : "Importă certificat rădăcină",
     "Administrator documentation" : "Documentație pentru administrare",
+    "Online documentation" : "Documentație online",
     "Forum" : "Forum",
+    "Commercial support" : "Suport comercial",
     "None" : "Niciuna",
     "Login" : "Autentificare",
     "Plain" : "Plain",
@@ -111,8 +155,8 @@ OC.L10N.register(
     "Start migration" : "Pornește migrarea",
     "Security & setup warnings" : "Alerte de securitate & configurare",
     "All checks passed." : "Toate verificările s-au terminat fără erori.",
-    "Version" : "Versiunea",
     "Execute one task with each page loaded" : "Execută o sarcină la fiecare pagină încărcată",
+    "Version" : "Versiunea",
     "Sharing" : "Partajare",
     "Allow apps to use the Share API" : "Permite aplicațiilor să folosească API-ul de partajare",
     "Allow users to share via link" : "Permite utilizatorilor să partajeze via link",
@@ -125,6 +169,8 @@ OC.L10N.register(
     "Allow resharing" : "Permite repartajarea",
     "Allow sharing with groups" : "Permite partajarea cu grupuri",
     "Exclude groups from sharing" : "Exclude grupuri de la partajare",
+    "Tips & tricks" : "Tips & tricks",
+    "How to do backups" : "Cum să faci copii de rezervă",
     "Profile picture" : "Imagine de profil",
     "Upload new" : "Încarcă una nouă",
     "Select from Files" : "Selectează din fișiere",
@@ -133,6 +179,7 @@ OC.L10N.register(
     "Cancel" : "Anulare",
     "Choose as profile picture" : "Alege ca imagine de profil",
     "Full name" : "Nume complet",
+    "Email" : "Email",
     "Your email address" : "Adresa ta de email",
     "Phone number" : "Număr telefon",
     "Your phone number" : "Numărul tău de telefon",
@@ -141,6 +188,7 @@ OC.L10N.register(
     "Website" : "Site web",
     "Link https://…" : "Link https://…",
     "Twitter" : "Twitter",
+    "Language" : "Limba",
     "Help translate" : "Ajută la traducere",
     "Password" : "Parolă",
     "Current password" : "Parola curentă",
@@ -149,73 +197,25 @@ OC.L10N.register(
     "Device" : "Dispozitiv",
     "App name" : "Numele aplicației",
     "Username" : "Nume utilizator",
-    "Enabled apps" : "Aplicații active",
-    "Migration Completed" : "Migrare încheiată",
-    "Group already exists." : "Grupul există deja.",
-    "Unable to add group." : "Nu se poate adăuga grupul.",
-    "Unable to delete group." : "Nu se poate șterge grupul.",
-    "No valid group selected" : "Niciun grup valid selectat",
-    "A user with that name already exists." : "Există deja un utilizator cu acest nume.",
-    "Unable to create user." : "Imposibil de creat utilizatorul.",
-    "Unable to delete user." : "Imposibil de șters utilizatorul.",
-    "Error while enabling user." : "Eroare în timpul activării utilizatorului.",
-    "Error while disabling user." : "Eroare în timpul dezactivării utilizatorului.",
-    "Your full name has been changed." : "Numele tău complet a fost schimbat.",
-    "Forbidden" : "Interzis",
-    "Invalid user" : "Utilizator invalid",
-    "Unable to change mail address" : "Nu s-a putut schimba adresa email",
-    "Email saved" : "E-mail salvat",
-    "Password confirmation is required" : "Confirmarea parolei este necesară",
-    "Are you really sure you want add {domain} as trusted domain?" : "Ești sigur că vrei sa adaugi {domain} ca domeniu de încredere?",
-    "Add trusted domain" : "Adaugă domeniu de încredere",
-    "All" : "Toate ",
-    "No apps found for your version" : "Nu au fost găsite aplicații pentru versiunea ta",
-    "Error while disabling app" : "Eroare în timpul dezactivării aplicației",
-    "Disable" : "Dezactivați",
-    "Error while enabling app" : "Eroare în timpul activării applicației",
-    "Updated" : "Actualizat",
-    "Approved" : "Aprobat",
-    "Experimental" : "Experimental",
-    "Unable to delete {objName}" : "Nu s-a putut șterge {objName}",
-    "Error creating group: {message}" : "Eroare la crearea grupului: {message}",
-    "A valid group name must be provided" : "Trebuie furnizat un nume de grup valid",
-    "deleted {groupName}" : "{groupName} s-a șters",
-    "undo" : "Anulează ultima acțiune",
-    "never" : "niciodată",
-    "deleted {userName}" : "{userName} șters",
-    "Add group" : "Adaugă grup",
-    "Invalid quota value \"{val}\"" : "Valoare cotă invalidă \"{val}\"",
-    "no group" : "niciun grup",
-    "Password successfully changed" : "Parola a fost modificată cu succes.",
-    "Changing the password will result in data loss, because data recovery is not available for this user" : "Schimbarea parolei va rezulta în pierderea datelor deoarece recuperarea acestora nu este disponibilă pentru acest utilizator",
-    "A valid username must be provided" : "Trebuie să furnizaţi un nume de utilizator valid",
-    "Error creating user: {message}" : "Eroare la crearea utilizatorului: {message}",
-    "A valid password must be provided" : "Trebuie să furnizaţi o parolă validă",
-    "A valid email must be provided" : "Trebuie furnizată o adresă email validă",
-    "Tips & tricks" : "Tips & tricks",
-    "How to do backups" : "Cum să faci copii de rezervă",
-    "This app has an update available." : "Este disponibilă o actualizare pentru această aplicație.",
-    "by %s" : "de %s",
-    "%s-licensed" : "%s-licențiat",
-    "Documentation:" : "Documentație:",
-    "Admin documentation" : "Documentație pentru administrare",
-    "Report a bug" : "Raportează un defect",
-    "Show description …" : "Arată descriere ...",
-    "Hide description …" : "Ascunde descriere ...",
-    "Enable only for specific groups" : "Activează doar pentru grupuri specifice",
-    "Online documentation" : "Documentație online",
-    "Commercial support" : "Suport comercial",
-    "E-Mail" : "Email",
-    "Create" : "Crează",
-    "Admin Recovery Password" : "Parolă de recuperare a Administratorului",
-    "Enter the recovery password in order to recover the users files during password change" : "Introdu parola de recuperare pentru a recupera fișierele utilizatorilor în timpul schimbării parolei",
+    "Settings" : "Setări",
+    "Everyone" : "Toți",
+    "Admins" : "Administratori",
     "Disabled" : "Dezactivați",
+    "Unlimited" : "Nelimitată",
     "Other" : "Altele",
     "Quota" : "Cotă",
+    "E-Mail" : "Email",
+    "Admin Recovery Password" : "Parolă de recuperare a Administratorului",
+    "Enter the recovery password in order to recover the users files during password change" : "Introdu parola de recuperare pentru a recupera fișierele utilizatorilor în timpul schimbării parolei",
     "change full name" : "schimbă numele complet",
     "set new password" : "setează parolă nouă",
     "change email address" : "schimbă adresa email",
     "Default" : "Implicită",
-    "{size} used" : "{size} folosită"
+    "Migration Completed" : "Migrare încheiată",
+    "Are you really sure you want add {domain} as trusted domain?" : "Ești sigur că vrei sa adaugi {domain} ca domeniu de încredere?",
+    "Add trusted domain" : "Adaugă domeniu de încredere",
+    "A valid password must be provided" : "Trebuie să furnizaţi o parolă validă",
+    "A valid email must be provided" : "Trebuie furnizată o adresă email validă",
+    "Create" : "Crează"
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
